@@ -4,9 +4,10 @@ import javax.inject.Inject;
 import javax.ws.rs.GET;
 import javax.ws.rs.Path;
 import javax.ws.rs.Produces;
-import javax.ws.rs.QueryParam;
 import javax.ws.rs.core.MediaType;
 
+import org.jboss.resteasy.reactive.RestQuery;
+
 import io.quarkus.qute.Template;
 import io.quarkus.qute.TemplateInstance;
 
@@ -18,7 +19,7 @@ public class HelloResource {
 
     @GET
     @Produces(MediaType.TEXT_HTML)
-    public TemplateInstance get(@QueryParam("name") String name) {
+    public TemplateInstance get(@RestQuery String name) {
         return hello.data("name", name);
     }
 
